<?php
/**
 * @package MHM OS
 *
 * APPLICATION-WIDE CONFIGURATION SETTINGS
 *
 * This file contains application-wide configuration settings.  The settings
 * here will be the same regardless of the machine on which the app is running.
 *
 * This configuration should be added to version control.
 *
 * No settings should be added to this file that would need to be changed
 * on a per-machine basic (ie local, staging or production).  Any
 * machine-specific settings should be added to _machine_config.php
 */

/**
 * APPLICATION ROOT DIRECTORY
 * If the application doesn't detect this correctly then it can be set explicitly
 */
if (!GlobalConfig::$APP_ROOT) GlobalConfig::$APP_ROOT = realpath("./");

/**
 * check is needed to ensure asp_tags is not enabled
 */
if (ini_get('asp_tags')) 
	die('<h3>Server Configuration Problem: asp_tags is enabled, but is not compatible with Savant.</h3>'
	. '<p>You can disable asp_tags in .htaccess, php.ini or generate your app with another template engine such as Smarty.</p>');

/**
 * INCLUDE PATH
 * Adjust the include path as necessary so PHP can locate required libraries
 */
set_include_path(
		GlobalConfig::$APP_ROOT . '/libs/' . PATH_SEPARATOR .
		'phar://' . GlobalConfig::$APP_ROOT . '/libs/phreeze-3.3.8.phar' . PATH_SEPARATOR .
		GlobalConfig::$APP_ROOT . '/../phreeze/libs' . PATH_SEPARATOR .
		GlobalConfig::$APP_ROOT . '/vendor/phreeze/phreeze/libs/' . PATH_SEPARATOR .
		get_include_path()
);

/**
 * COMPOSER AUTOLOADER
 * Uncomment if Composer is being used to manage dependencies
 */
// $loader = require 'vendor/autoload.php';
// $loader->setUseIncludePath(true);

/**
 * SESSION CLASSES
 * Any classes that will be stored in the session can be added here
 * and will be pre-loaded on every page
 */
require_once "App/ExampleUser.php";

/**
 * RENDER ENGINE
 * You can use any template system that implements
 * IRenderEngine for the view layer.  Phreeze provides pre-built
 * implementations for Smarty, Savant and plain PHP.
 */
require_once 'verysimple/Phreeze/SavantRenderEngine.php';
GlobalConfig::$TEMPLATE_ENGINE = 'SavantRenderEngine';
GlobalConfig::$TEMPLATE_PATH = GlobalConfig::$APP_ROOT . '/templates/';

/**
 * ROUTE MAP
 * The route map connects URLs to Controller+Method and additionally maps the
 * wildcards to a named parameter so that they are accessible inside the
 * Controller without having to parse the URL for parameters such as IDs
 */
GlobalConfig::$ROUTE_MAP = array(

	// default controller when no route specified
	'GET:' => array('route' => 'Default.Home'),
		
	// example authentication routes
	'GET:loginform' => array('route' => 'SecureExample.LoginForm'),
	'POST:login' => array('route' => 'SecureExample.Login'),
	'GET:secureuser' => array('route' => 'SecureExample.UserPage'),
	'GET:secureadmin' => array('route' => 'SecureExample.AdminPage'),
	'GET:logout' => array('route' => 'SecureExample.Logout'),
		
	// Agenda
	'GET:agendas' => array('route' => 'Agenda.ListView'),
	'GET:agenda/(:num)' => array('route' => 'Agenda.SingleView', 'params' => array('id' => 1)),
	'GET:api/agendas' => array('route' => 'Agenda.Query'),
	'POST:api/agenda' => array('route' => 'Agenda.Create'),
	'GET:api/agenda/(:num)' => array('route' => 'Agenda.Read', 'params' => array('id' => 2)),
	'PUT:api/agenda/(:num)' => array('route' => 'Agenda.Update', 'params' => array('id' => 2)),
	'DELETE:api/agenda/(:num)' => array('route' => 'Agenda.Delete', 'params' => array('id' => 2)),
		
	// Cidades
	'GET:cidadeses' => array('route' => 'Cidades.ListView'),
	'GET:cidades/(:num)' => array('route' => 'Cidades.SingleView', 'params' => array('id' => 1)),
	'GET:api/cidadeses' => array('route' => 'Cidades.Query'),
	'POST:api/cidades' => array('route' => 'Cidades.Create'),
	'GET:api/cidades/(:num)' => array('route' => 'Cidades.Read', 'params' => array('id' => 2)),
	'PUT:api/cidades/(:num)' => array('route' => 'Cidades.Update', 'params' => array('id' => 2)),
	'DELETE:api/cidades/(:num)' => array('route' => 'Cidades.Delete', 'params' => array('id' => 2)),
		
	// EnqPerg
	'GET:enqpergs' => array('route' => 'EnqPerg.ListView'),
	'GET:enqperg/(:num)' => array('route' => 'EnqPerg.SingleView', 'params' => array('codigo' => 1)),
	'GET:api/enqpergs' => array('route' => 'EnqPerg.Query'),
	'POST:api/enqperg' => array('route' => 'EnqPerg.Create'),
	'GET:api/enqperg/(:num)' => array('route' => 'EnqPerg.Read', 'params' => array('codigo' => 2)),
	'PUT:api/enqperg/(:num)' => array('route' => 'EnqPerg.Update', 'params' => array('codigo' => 2)),
	'DELETE:api/enqperg/(:num)' => array('route' => 'EnqPerg.Delete', 'params' => array('codigo' => 2)),
		
	// EnqResp
	'GET:enqresps' => array('route' => 'EnqResp.ListView'),
	'GET:enqresp/(:num)' => array('route' => 'EnqResp.SingleView', 'params' => array('codigo' => 1)),
	'GET:api/enqresps' => array('route' => 'EnqResp.Query'),
	'POST:api/enqresp' => array('route' => 'EnqResp.Create'),
	'GET:api/enqresp/(:num)' => array('route' => 'EnqResp.Read', 'params' => array('codigo' => 2)),
	'PUT:api/enqresp/(:num)' => array('route' => 'EnqResp.Update', 'params' => array('codigo' => 2)),
	'DELETE:api/enqresp/(:num)' => array('route' => 'EnqResp.Delete', 'params' => array('codigo' => 2)),
		
	// Eventos
	'GET:eventoses' => array('route' => 'Eventos.ListView'),
	'GET:eventos/(:num)' => array('route' => 'Eventos.SingleView', 'params' => array('id' => 1)),
	'GET:api/eventoses' => array('route' => 'Eventos.Query'),
	'POST:api/eventos' => array('route' => 'Eventos.Create'),
	'GET:api/eventos/(:num)' => array('route' => 'Eventos.Read', 'params' => array('id' => 2)),
	'PUT:api/eventos/(:num)' => array('route' => 'Eventos.Update', 'params' => array('id' => 2)),
	'DELETE:api/eventos/(:num)' => array('route' => 'Eventos.Delete', 'params' => array('id' => 2)),
		
	// Guia
	'GET:guias' => array('route' => 'Guia.ListView'),
	'GET:guia/(:num)' => array('route' => 'Guia.SingleView', 'params' => array('id' => 1)),
	'GET:api/guias' => array('route' => 'Guia.Query'),
	'POST:api/guia' => array('route' => 'Guia.Create'),
	'GET:api/guia/(:num)' => array('route' => 'Guia.Read', 'params' => array('id' => 2)),
	'PUT:api/guia/(:num)' => array('route' => 'Guia.Update', 'params' => array('id' => 2)),
	'DELETE:api/guia/(:num)' => array('route' => 'Guia.Delete', 'params' => array('id' => 2)),
		
	// Guiatp
	'GET:guiatps' => array('route' => 'Guiatp.ListView'),
	'GET:guiatp/(:num)' => array('route' => 'Guiatp.SingleView', 'params' => array('id' => 1)),
	'GET:api/guiatps' => array('route' => 'Guiatp.Query'),
	'POST:api/guiatp' => array('route' => 'Guiatp.Create'),
	'GET:api/guiatp/(:num)' => array('route' => 'Guiatp.Read', 'params' => array('id' => 2)),
	'PUT:api/guiatp/(:num)' => array('route' => 'Guiatp.Update', 'params' => array('id' => 2)),
	'DELETE:api/guiatp/(:num)' => array('route' => 'Guiatp.Delete', 'params' => array('id' => 2)),
		
	// Midia
	'GET:midias' => array('route' => 'Midia.ListView'),
	'GET:midia/(:num)' => array('route' => 'Midia.SingleView', 'params' => array('id' => 1)),
	'GET:api/midias' => array('route' => 'Midia.Query'),
	'POST:api/midia' => array('route' => 'Midia.Create'),
	'GET:api/midia/(:num)' => array('route' => 'Midia.Read', 'params' => array('id' => 2)),
	'PUT:api/midia/(:num)' => array('route' => 'Midia.Update', 'params' => array('id' => 2)),
	'DELETE:api/midia/(:num)' => array('route' => 'Midia.Delete', 'params' => array('id' => 2)),
		
	// MidiaGrp
	'GET:midiagrps' => array('route' => 'MidiaGrp.ListView'),
	'GET:midiagrp/(:num)' => array('route' => 'MidiaGrp.SingleView', 'params' => array('id' => 1)),
	'GET:api/midiagrps' => array('route' => 'MidiaGrp.Query'),
	'POST:api/midiagrp' => array('route' => 'MidiaGrp.Create'),
	'GET:api/midiagrp/(:num)' => array('route' => 'MidiaGrp.Read', 'params' => array('id' => 2)),
	'PUT:api/midiagrp/(:num)' => array('route' => 'MidiaGrp.Update', 'params' => array('id' => 2)),
	'DELETE:api/midiagrp/(:num)' => array('route' => 'MidiaGrp.Delete', 'params' => array('id' => 2)),
		
	// Noticias
	'GET:noticiases' => array('route' => 'Noticias.ListView'),
	'GET:noticias/(:num)' => array('route' => 'Noticias.SingleView', 'params' => array('id' => 1)),
	'GET:api/noticiases' => array('route' => 'Noticias.Query'),
	'POST:api/noticias' => array('route' => 'Noticias.Create'),
	'GET:api/noticias/(:num)' => array('route' => 'Noticias.Read', 'params' => array('id' => 2)),
	'PUT:api/noticias/(:num)' => array('route' => 'Noticias.Update', 'params' => array('id' => 2)),
	'DELETE:api/noticias/(:num)' => array('route' => 'Noticias.Delete', 'params' => array('id' => 2)),
		
	// NoticiasSec
	'GET:noticiassecs' => array('route' => 'NoticiasSec.ListView'),
	'GET:noticiassec/(:num)' => array('route' => 'NoticiasSec.SingleView', 'params' => array('id' => 1)),
	'GET:api/noticiassecs' => array('route' => 'NoticiasSec.Query'),
	'POST:api/noticiassec' => array('route' => 'NoticiasSec.Create'),
	'GET:api/noticiassec/(:num)' => array('route' => 'NoticiasSec.Read', 'params' => array('id' => 2)),
	'PUT:api/noticiassec/(:num)' => array('route' => 'NoticiasSec.Update', 'params' => array('id' => 2)),
	'DELETE:api/noticiassec/(:num)' => array('route' => 'NoticiasSec.Delete', 'params' => array('id' => 2)),
		
	// Noticiasrp
	'GET:noticiasrps' => array('route' => 'Noticiasrp.ListView'),
	'GET:noticiasrp/(:num)' => array('route' => 'Noticiasrp.SingleView', 'params' => array('id' => 1)),
	'GET:api/noticiasrps' => array('route' => 'Noticiasrp.Query'),
	'POST:api/noticiasrp' => array('route' => 'Noticiasrp.Create'),
	'GET:api/noticiasrp/(:num)' => array('route' => 'Noticiasrp.Read', 'params' => array('id' => 2)),
	'PUT:api/noticiasrp/(:num)' => array('route' => 'Noticiasrp.Update', 'params' => array('id' => 2)),
	'DELETE:api/noticiasrp/(:num)' => array('route' => 'Noticiasrp.Delete', 'params' => array('id' => 2)),
		
	// Os
	'GET:oses' => array('route' => 'Os.ListView'),
	'GET:os/(:num)' => array('route' => 'Os.SingleView', 'params' => array('id' => 1)),
	'GET:api/oses' => array('route' => 'Os.Query'),
	'POST:api/os' => array('route' => 'Os.Create'),
	'GET:api/os/(:num)' => array('route' => 'Os.Read', 'params' => array('id' => 2)),
	'PUT:api/os/(:num)' => array('route' => 'Os.Update', 'params' => array('id' => 2)),
	'DELETE:api/os/(:num)' => array('route' => 'Os.Delete', 'params' => array('id' => 2)),
		
	// Representantes
	'GET:representanteses' => array('route' => 'Representantes.ListView'),
	'GET:representantes/(:num)' => array('route' => 'Representantes.SingleView', 'params' => array('id' => 1)),
	'GET:api/representanteses' => array('route' => 'Representantes.Query'),
	'POST:api/representantes' => array('route' => 'Representantes.Create'),
	'GET:api/representantes/(:num)' => array('route' => 'Representantes.Read', 'params' => array('id' => 2)),
	'PUT:api/representantes/(:num)' => array('route' => 'Representantes.Update', 'params' => array('id' => 2)),
	'DELETE:api/representantes/(:num)' => array('route' => 'Representantes.Delete', 'params' => array('id' => 2)),
		
	// RepresentantesCidades
	'GET:representantescidadeses' => array('route' => 'RepresentantesCidades.ListView'),
	'GET:representantescidades/(:num)' => array('route' => 'RepresentantesCidades.SingleView', 'params' => array('id' => 1)),
	'GET:api/representantescidadeses' => array('route' => 'RepresentantesCidades.Query'),
	'POST:api/representantescidades' => array('route' => 'RepresentantesCidades.Create'),
	'GET:api/representantescidades/(:num)' => array('route' => 'RepresentantesCidades.Read', 'params' => array('id' => 2)),
	'PUT:api/representantescidades/(:num)' => array('route' => 'RepresentantesCidades.Update', 'params' => array('id' => 2)),
	'DELETE:api/representantescidades/(:num)' => array('route' => 'RepresentantesCidades.Delete', 'params' => array('id' => 2)),
		
	// Usuarios
	'GET:usuarioses' => array('route' => 'Usuarios.ListView'),
	'GET:usuarios/(:num)' => array('route' => 'Usuarios.SingleView', 'params' => array('id' => 1)),
	'GET:api/usuarioses' => array('route' => 'Usuarios.Query'),
	'POST:api/usuarios' => array('route' => 'Usuarios.Create'),
	'GET:api/usuarios/(:num)' => array('route' => 'Usuarios.Read', 'params' => array('id' => 2)),
	'PUT:api/usuarios/(:num)' => array('route' => 'Usuarios.Update', 'params' => array('id' => 2)),
	'DELETE:api/usuarios/(:num)' => array('route' => 'Usuarios.Delete', 'params' => array('id' => 2)),
		
	// Videos
	'GET:videoses' => array('route' => 'Videos.ListView'),
	'GET:videos/(:num)' => array('route' => 'Videos.SingleView', 'params' => array('id' => 1)),
	'GET:api/videoses' => array('route' => 'Videos.Query'),
	'POST:api/videos' => array('route' => 'Videos.Create'),
	'GET:api/videos/(:num)' => array('route' => 'Videos.Read', 'params' => array('id' => 2)),
	'PUT:api/videos/(:num)' => array('route' => 'Videos.Update', 'params' => array('id' => 2)),
	'DELETE:api/videos/(:num)' => array('route' => 'Videos.Delete', 'params' => array('id' => 2)),

	// catch any broken API urls
	'GET:api/(:any)' => array('route' => 'Default.ErrorApi404'),
	'PUT:api/(:any)' => array('route' => 'Default.ErrorApi404'),
	'POST:api/(:any)' => array('route' => 'Default.ErrorApi404'),
	'DELETE:api/(:any)' => array('route' => 'Default.ErrorApi404')
);

/**
 * FETCHING STRATEGY
 * You may uncomment any of the lines below to specify always eager fetching.
 * Alternatively, you can copy/paste to a specific page for one-time eager fetching
 * If you paste into a controller method, replace $G_PHREEZER with $this->Phreezer
 */
// $GlobalConfig->GetInstance()->GetPhreezer()->SetLoadType("EnqResp","fk_perg",KM_LOAD_EAGER); // KM_LOAD_INNER | KM_LOAD_EAGER | KM_LOAD_LAZY
// $GlobalConfig->GetInstance()->GetPhreezer()->SetLoadType("Guia","fk_giatp",KM_LOAD_EAGER); // KM_LOAD_INNER | KM_LOAD_EAGER | KM_LOAD_LAZY
// $GlobalConfig->GetInstance()->GetPhreezer()->SetLoadType("Midia","fk_mediagrp",KM_LOAD_EAGER); // KM_LOAD_INNER | KM_LOAD_EAGER | KM_LOAD_LAZY
// $GlobalConfig->GetInstance()->GetPhreezer()->SetLoadType("Noticias","FK_SECAO",KM_LOAD_EAGER); // KM_LOAD_INNER | KM_LOAD_EAGER | KM_LOAD_LAZY
?>